﻿using System;
using Windows.ApplicationModel.Activation;
using Windows.ApplicationModel.DataTransfer;
using Windows.Storage;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Media.Imaging;

// The Share Target Contract item template is documented at http://go.microsoft.com/fwlink/?LinkId=234241

namespace Win8Contracts
{
	/// <summary>
	/// This page allows other applications to share content through this application.
	/// </summary>
	public sealed partial class ShareTargetPage : Win8Contracts.Common.LayoutAwarePage
	{
		/// <summary>
		/// Provides a channel to communicate with Windows about the sharing operation.
		/// </summary>
		private Windows.ApplicationModel.DataTransfer.ShareTarget.ShareOperation _shareOperation;

		public ShareTargetPage()
		{
			this.InitializeComponent();
		}

		/// <summary>
		/// Invoked when another application wants to share content through this application.
		/// </summary>
		/// <param name="args">Activation data used to coordinate the process with Windows.</param>
		public async void Activate(ShareTargetActivatedEventArgs args)
		{
			this._shareOperation = args.ShareOperation;

			// Communicate metadata about the shared content through the view model
			var shareProperties = this._shareOperation.Data.Properties;
			var thumbnailImage = new BitmapImage();
			this.DefaultViewModel["Title"] = shareProperties.Title;
			this.DefaultViewModel["Description"] = shareProperties.Description;
			this.DefaultViewModel["Image"] = thumbnailImage;
			this.DefaultViewModel["Sharing"] = false;
			this.DefaultViewModel["ShowImage"] = false;
			this.DefaultViewModel["Comment"] = String.Empty;
			this.DefaultViewModel["SupportsComment"] = true;
			Window.Current.Content = this;
			Window.Current.Activate();

			// Update the shared content's thumbnail image in the background
			if (shareProperties.Thumbnail != null)
			{
				var stream = await shareProperties.Thumbnail.OpenReadAsync();
				thumbnailImage.SetSource(stream);
				this.DefaultViewModel["ShowImage"] = true;
			}
		}

		/// <summary>
		/// Invoked when the user clicks the Share button.
		/// </summary>
		/// <param name="sender">Instance of Button used to initiate sharing.</param>
		/// <param name="e">Event data describing how the button was clicked.</param>
		private async void ShareButton_Click(object sender, RoutedEventArgs e)
		{
			this.DefaultViewModel["Sharing"] = true;
			this._shareOperation.ReportStarted();

			// TODO: Perform work appropriate to your sharing scenario using
			//       this._shareOperation.Data, typically with additional information captured
			//       through custom user interface elements added to this page such as 
			//       this.DefaultViewModel["Comment"]

			if(_shareOperation.Data.Contains(StandardDataFormats.Bitmap))
			{
				var stream = await _shareOperation.Data.GetBitmapAsync();
				var readStream = await stream.OpenReadAsync();
				var file = await KnownFolders.PicturesLibrary.CreateFileAsync(this.DefaultViewModel["Title"].ToString() + ".png", CreationCollisionOption.GenerateUniqueName);
				var fileStream = await file.OpenAsync(FileAccessMode.ReadWrite);
				await RandomAccessStream.CopyAndCloseAsync(readStream, fileStream);
			}

			this._shareOperation.ReportCompleted();
		}
	}
}
